/*
 * This is part of XmlEditor, a graphical editor for XML files
 * Copyright (C) 2001 CERN - Sebastien Ponce
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * Contacts :
 *   sebastien.ponce@polytechnique.org
 *   http://lhcb-comp.web.cern.ch/lhcb-comp/
 *   http://www.cern.ch
 */

package ch.cern.lhcb.xmleditor.gui;

import javax.swing.JInternalFrame;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import javax.swing.event.InternalFrameAdapter;
import javax.swing.event.InternalFrameEvent;

import ch.cern.lhcb.xmleditor.Editor;

/**
 * This class allows to show a text inside an internal Frame
 */
public class TextView extends JInternalFrame {

    /**
     * a pointer on the XmlEditor that uses this TextView
     */
    private Editor editor;

    /**
     * this is a constructor. It takes the text to be displayed and a title as
     * parameters
     * 
     * @param text the text to be displayed
     * @param editor a pointer on the underlying editor
     */
    public TextView(String text, String title, Editor editor) {
        // Initialisation
        super(title, true, // resizable
                true, // closable
                true, // maximizable
                true);// iconifiable
        // saves the editor pointer
        this.editor = editor;
        // sets the window size or call pack...
        setSize(450, 450);
        // adds an InternalFrameListener to catch closing of this TreeView
        addInternalFrameListener(new FrameAdapter());
        // creates the textArea
        JTextArea textArea = new JTextArea(text);
        // prevent edition
        textArea.setEditable(false);
        // builds a scrollPane to encapsulate the TextArea and puts it into the
        // window
        getContentPane().add(new JScrollPane(textArea));
    }

    /**
     * this is a listener on TextView. It allows to catch frame events like
     * closing
     */
    private class FrameAdapter extends InternalFrameAdapter {

        /**
         * Invoked when an internal frame is in the process of being closed. The
         * close operation can be overridden at this point.
         * 
         * @param e the closing event
         */
        public void internalFrameClosing(InternalFrameEvent e) {
            TextView.this.editor.internalFrameClosing(TextView.this);
        }
    }

}