/*
 * com.simulogic.cese -- Cell Electrophysiology Simulation Environment (CESE)
 * 
 * Copyright (C) 1999 - 2005 Sergey Missan
 * 
 * Dalhousie Univ., Halifax, NS, Canada
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place, Suite 330, Boston, MA 02111-1307 USA
 *  
 */

package com.simulogic.cese.actions;

import java.awt.event.ActionEvent;
import java.io.File;
import java.io.FileInputStream;
import java.io.ObjectInputStream;

import javax.swing.JFileChooser;
import javax.swing.beanbuilder.CustomObjectInputStream;
import javax.swing.beanbuilder.JarClassLoader;

import com.simulogic.cese.CESE;
import com.simulogic.cese.ModelManager;
import com.simulogic.cese.ResourceManager;
import com.simulogic.cese.UserHome;
import com.simulogic.utils.ActionSupport;
import com.simulogic.utils.ExceptionDialog;
import com.simulogic.utils.ExtensionFileFilter;

/**
 * OpenParams action implementation
 */
public class OpenParamsAction extends ActionSupport implements
		java.beans.PropertyChangeListener {

	private File dir, file;

	private ModelManager manager;

	/** 
	 * Creates new OpenParamsAction  
     *  
     * @param m model manager
     */
	public OpenParamsAction(ModelManager m) {
		this();
		manager = m;
		manager.addPropertyChangeListener(this);
	}

	/** Creates new OpenParamsAction */
	public OpenParamsAction() {
		super(ResourceManager.getResource("Open_Parameters..."),
				ResourceManager.getResource("Open_parameters"), ResourceManager
						.getResource("open_params_image"));
	}

	public void actionPerformed(ActionEvent evt) {
		if (dir == null)
			dir = new File(UserHome.CESE_HOME + UserHome.FS
					+ ResourceManager.getResource("params_dir"));

		ObjectInputStream in = null;
		try {
			JFileChooser filechooser = new JFileChooser(dir);
			filechooser.setDialogTitle(ResourceManager
					.getResource("Load_Model_Parameters"));
			ExtensionFileFilter preferredFilter = new ExtensionFileFilter(
					ResourceManager.getResource("mdl_extension"),
					ResourceManager.getResource("Model_Parameters_Files"));
			filechooser.addChoosableFileFilter(preferredFilter);
			filechooser.setFileFilter(preferredFilter);

			int retVal = filechooser.showOpenDialog(CESE.getEnvironment());
			if (retVal == JFileChooser.APPROVE_OPTION) {
				file = filechooser.getSelectedFile();
				dir = filechooser.getCurrentDirectory();
				if (file.getPath() == null)
					return;

				in = new CustomObjectInputStream(new FileInputStream(file
						.getPath()), JarClassLoader.getJarClassLoader());

				Object lm = in.readObject();

				manager.getModelInfo().getHistory().setTreeSelection(
						manager.getExportTreeSelection());

				boolean res = manager.loadModel(lm);
				if (res) {
					manager.getModelInfo().getHistory().setParametersFile(file);
					manager.getRecentParameters().addFileName(file.getPath());
				}
				
				manager.getModelInfo().setModified(false);
				manager.changeModel();
			}
		} catch (Exception e) {
			ExceptionDialog.showExceptionDialog(ResourceManager
					.getResource("Error"), ResourceManager
					.getResource("Error_loading_parameters_file."), e);
		} finally {
			try {
				in.close();
			} catch (Exception ex) {
			}
		}
	}

	public void propertyChange(java.beans.PropertyChangeEvent evt) {
		if (evt.getPropertyName().equals("model_control"))
			this.setEnabled(((Boolean) evt.getNewValue()).booleanValue());
	}
}