/*
 * com.simulogic.cese -- Cell Electrophysiology Simulation Environment (CESE)
 * 
 * Copyright (C) 1999 - 2005 Sergey Missan
 * 
 * Dalhousie Univ., Halifax, NS, Canada
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place, Suite 330, Boston, MA 02111-1307 USA
 *  
 */

package com.simulogic.cese.actions;

import java.awt.event.ActionEvent;
import java.io.File;
import java.io.FileOutputStream;
import java.io.ObjectOutputStream;

import javax.swing.JFileChooser;
import javax.swing.JOptionPane;

import com.simulogic.cese.CESE;
import com.simulogic.cese.ModelManager;
import com.simulogic.cese.ResourceManager;
import com.simulogic.cese.UserHome;
import com.simulogic.utils.ActionSupport;
import com.simulogic.utils.ExceptionDialog;
import com.simulogic.utils.ExtensionFileFilter;

/**
 * SaveParamsAs action implementation
 */
public class SaveParamsAsAction extends ActionSupport implements
		java.beans.PropertyChangeListener {

	private File dir, file;

	private ModelManager manager;

	/** 
	 * Creates new SaveParamsAsAction  
     *  
     * @param m model manager
     */
	public SaveParamsAsAction(ModelManager m) {
		this();
		manager = m;
		manager.addPropertyChangeListener(this);
	}

	/** Creates new SaveParamsAsAction */
	public SaveParamsAsAction() {
		super(ResourceManager.getResource("Save_Parameters_As"),
				ResourceManager.getResource("Save_parameters_as"));
	}

	public void actionPerformed(ActionEvent evt) {
		if (dir == null)
			dir = new File(UserHome.CESE_HOME + UserHome.FS
					+ ResourceManager.getResource("params_dir"));

		ObjectOutputStream out = null;
		try {
			JFileChooser filechooser = new JFileChooser(dir);
			filechooser.setDialogTitle(ResourceManager
					.getResource("Save_Model_Parameters"));

			ExtensionFileFilter mdlFilter = new ExtensionFileFilter(
					ResourceManager.getResource("mdl_extension"),
					ResourceManager.getResource("Model_Parameters_Files"));
			filechooser.addChoosableFileFilter(mdlFilter);

			ExtensionFileFilter txtFilter = new ExtensionFileFilter(
					ResourceManager.getResource("txt_extension"),
					ResourceManager.getResource("Parameters_Text_Files"));
			filechooser.addChoosableFileFilter(txtFilter);

			filechooser.setFileFilter(mdlFilter);

			int retVal = filechooser.showSaveDialog(CESE.getEnvironment());
			if (retVal == JFileChooser.APPROVE_OPTION) {
				file = filechooser.getSelectedFile();
				dir = filechooser.getCurrentDirectory();
				if (file.getPath() == null)
					return;

				ExtensionFileFilter filter = (ExtensionFileFilter) filechooser
						.getFileFilter();

				// Add default extension if no extension is given by the user
				if (filter.getExtension(file) == null)
					file = new java.io.File(file.getAbsolutePath() + "."
							+ filter.getExtension());

				if (file.exists()) {
					int n = JOptionPane.showConfirmDialog(
							CESE.getEnvironment(), ResourceManager
									.getResource("Overwrite_file_")
									+ file.getPath() + " ?", ResourceManager
									.getResource("File_already_exists"),
							JOptionPane.YES_NO_OPTION);
					if (n == JOptionPane.NO_OPTION)
						return;
				}

				if (filter.getExtension(file).equals(
						ResourceManager.getResource("mdl_extension"))) {
					out = new ObjectOutputStream(new FileOutputStream(file
							.getPath()));

					manager.getModelInfo().getHistory().setTreeSelection(
							manager.getExportTreeSelection());
			
					out.writeObject(manager.getModelInfo().getModel());
					manager.getModelInfo().getHistory().setParametersFile(file);
					manager.getRecentParameters().addFileName(file.getPath());
					
					manager.getModelInfo().setModified(false);
					manager.changeModel();
				} else {
					manager.exportParametersASCII(file.getPath());
				}			
			}
		} catch (Exception e) {
			ExceptionDialog.showExceptionDialog(ResourceManager
					.getResource("Error"), ResourceManager
					.getResource("Error_saving_parameters_file."), e);
		} finally {
			try {
				if (out != null)
					out.close();
			} catch (Exception ex) {
			}
		}
	}

	public void propertyChange(java.beans.PropertyChangeEvent evt) {
		if (evt.getPropertyName().equals("model_control"))
			this.setEnabled(((Boolean) evt.getNewValue()).booleanValue());
	}
}