/*
 * com.simulogic.cese -- Cell Electrophysiology Simulation Environment (CESE)
 *
 * Copyright (C) 1999 - 2005 Sergey Missan
 * 
 * Dalhousie Univ., Halifax, NS, Canada
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.simulogic.cese.updates;

import java.awt.Dimension;

import javax.swing.DefaultListModel;
import javax.swing.JComponent;
import javax.swing.JEditorPane;
import javax.swing.JScrollPane;
import javax.swing.JTabbedPane;
import javax.swing.ListSelectionModel;

import com.simulogic.cese.ResourceManager;
import com.simulogic.cese.UserHome;
import com.simulogic.utils.BrowserLauncher;

/**
 * Generates dialog box to check for available online updates
 */
public class UpdateOptions extends javax.swing.JDialog {

    /** A return status code - returned if Cancel button has been pressed */
    public static final int RET_CANCEL = 0;
    /** A return status code - returned if OK button has been pressed */
    public static final int RET_OK = 1;

    private UpdateFetcher fetcher = new UpdateFetcher();
    private String title;
    private String link;
    private String pubdate;

    /**
     * Generates dialog bobox to check for available online updates
     * 
     * @param parent parent frame
     */
    public UpdateOptions(java.awt.Frame parent) {
        super(parent, true);
        initComponents();
    }

    /**
     * @return the return status of this dialog - one of RET_OK or RET_CANCEL
     */
    public int getReturnStatus() {
        return returnStatus;
    }

    private void initComponents() {
        buttonPanel = new javax.swing.JPanel();
        okButton = new javax.swing.JButton();
        cancelButton = new javax.swing.JButton();
        listPanel = new javax.swing.JPanel();
        listScrollPane = new javax.swing.JScrollPane();
        updateList = new javax.swing.JList();
         
        changelogPanel = new JEditorPane("text/html", "");
        changelogPanel.setEditable(false);

        setTitle(ResourceManager.getResource("Update_Manager"));
        addWindowListener(new java.awt.event.WindowAdapter() {

            public void windowClosing(java.awt.event.WindowEvent evt) {
                closeDialog();
            }
        });

        buttonPanel
                .setLayout(new java.awt.FlowLayout(java.awt.FlowLayout.RIGHT));

        okButton.setText(ResourceManager.getResource("OK"));
        okButton.addActionListener(new java.awt.event.ActionListener() {

            public void actionPerformed(java.awt.event.ActionEvent evt) {
                okButtonActionPerformed();
            }
        });

        buttonPanel.add(okButton);

        cancelButton.setText(ResourceManager.getResource("Cancel"));
        cancelButton.addActionListener(new java.awt.event.ActionListener() {

            public void actionPerformed(java.awt.event.ActionEvent evt) {
                cancelButtonActionPerformed();
            }
        });

        // buttonPanel.add(cancelButton);

        getContentPane().add(buttonPanel, java.awt.BorderLayout.SOUTH);

        listPanel.setLayout(new java.awt.BorderLayout());

        listPanel.setBorder(new javax.swing.border.TitledBorder(
                new javax.swing.border.EtchedBorder(), ResourceManager
                        .getResource("Available_updates")));

        updateList.setModel(new DefaultListModel());
        updateList
                .setSelectionMode(ListSelectionModel.SINGLE_INTERVAL_SELECTION);
        updateList
                .addListSelectionListener(new javax.swing.event.ListSelectionListener() {

                    public void valueChanged(
                            javax.swing.event.ListSelectionEvent evt) {
                    	if (updateList.getSelectedIndex() != -1)
                        updateListValueChanged(evt);
                    }
                });
        listScrollPane.setViewportView(updateList);
        listScrollPane.setPreferredSize(new Dimension(250, 150));

        listPanel.add(listScrollPane, java.awt.BorderLayout.CENTER);
         
        JTabbedPane tabs = new JTabbedPane();
        tabs.addTab(ResourceManager.getResource("Updates"),
        		listPanel);
        tabs.addTab(ResourceManager.getResource("Changelog"), new JScrollPane(
                changelogPanel));
     
        for (int i = 0; i < tabs.getTabCount(); i++)
            ((JComponent) tabs.getComponentAt(i)).setPreferredSize(tabs
                    .getComponentAt(0).getPreferredSize());

        getContentPane().add(tabs, java.awt.BorderLayout.CENTER);
    }

    private void cancelButtonActionPerformed() {
        doClose(RET_CANCEL);
    }

    private void okButtonActionPerformed() {
        doClose(RET_OK);
    }

    private void setList() {
		((DefaultListModel) updateList.getModel()).clear();
		((DefaultListModel) updateList.getModel()).addElement(ResourceManager
				.getResource("Checking_for_updates"));

		com.simulogic.utils.SwingWorker worker = new com.simulogic.utils.SwingWorker() {
			String changelog="";

			public Object construct() {
				try {
					fetcher.fetchUpdate();
					changelog = fetcher.fetchChangelog();
					
					fetcher.setUpdateTime();

					title = fetcher.getTitle();
					link = fetcher.getLink();
					pubdate = fetcher.getPubdate();
				} catch (Exception e) {
				}
				return ResourceManager.getResource("Done");
			}

			public void finished() {
				fillChangelogPane(changelog);

				((DefaultListModel) updateList.getModel()).setElementAt(
						"<HTML>"
								+ "<u>"
								+ ResourceManager
										.getResource("Installed_version")
								+ "</u>"
								+ "<br>"
								+ "cese "
								+ UserHome.CESE_VERSION_MINOR
								+ "<br>"
								+ "<u>"
								+ ResourceManager
										.getResource("Available_version")
								+ "</u>" + "<br>" + title + "<br>" + "<a href="
								+ link + ">" + link + "</a>" + "</HTML>", 0);

			}
		};

		worker.start();
	}
    
    private void fillChangelogPane(String changes) {
        changelogPanel.setText(changes);
    }

    private void updateListValueChanged(javax.swing.event.ListSelectionEvent evt) {
        if (evt.getValueIsAdjusting()) return;
        try {
            BrowserLauncher.openURL(link);
        } catch (Exception e) {
        }
    }

    private void doClose(int retStatus) {
        returnStatus = retStatus;
        setVisible(false);
        dispose();
    }

    /**
	 * Closes the dialog
	 */
    private void closeDialog() {
        doClose(RET_CANCEL);
    }

    /**
	 * Overrides setVisible(boolean b) in <code>JDialog</code>
	 * 
	 * @param b
	 *            visibility
	 */
    public void setVisible(boolean b) {
        if (b == true) {
            setResizable(true);
            setList();
            pack();
            setResizable(false);
            getRootPane().setDefaultButton(okButton);
            setLocationRelativeTo(getOwner());
        }
        super.setVisible(b);
    }

    private javax.swing.JPanel listPanel;
    private javax.swing.JPanel buttonPanel;
    private javax.swing.JList updateList;
    private javax.swing.JButton okButton;
    private javax.swing.JButton cancelButton;
    private javax.swing.JScrollPane listScrollPane;
    private JEditorPane changelogPanel;

    private int returnStatus = RET_CANCEL;

}